@@ -1,7 +1,7 @@
 #!/usr/bin/perl -w
 use strict;
 ##########################################################################
-# $Id: logwatch.pl,v 1.113 2004/06/23 15:01:17 kirk Exp $
+# $Id: logwatch.pl,v 1.109 2004/02/03 19:14:59 kirk Exp $
 ##########################################################################
 # Most current version can always be found at:
 # ftp://ftp.logwatch.org/pub/redhat/RPMS
@@ -24,8 +24,8 @@ my $ConfigDir = "$BaseDir/conf";
 my $OSname = `uname -s`;
 chomp $OSname;
 
-my $Version = '5.2.2';
-my $VDate = '06/23/04';
+my $Version = '5.1';
+my $VDate = '02/03/04';
 
 #############################################################################
 
@@ -471,9 +471,8 @@ if ($Config{'debug'} > 7) {
 
 my $TempDir;
 my $UseMkTemp = $Config{'usemktemp'};
-my $MkTemp = $Config{'mktemp'} || '';
-if ($UseMkTemp and (-x $MkTemp)) {
-   $TempDir = `$MkTemp -d $Config{'tmpdir'}/logwatch.XXXXXXXX 2>/dev/null`;
+if ($UseMkTemp and (-x '/bin/mktemp')) {
+   $TempDir = `/bin/mktemp -d $Config{'tmpdir'}/logwatch.XXXXXXXX 2>/dev/null`;
    chomp($TempDir);
    unless (($? == 0) and $TempDir) {
       die "Failed to create $Config{'tmpdir'}/logwatch.XXXXXXXX with mktemp!!\nDoes your mktemp support the -d option??\nIf not, modify logwatch.conf accordingly.\n";
@@ -564,7 +563,7 @@ my $LogFile;
 foreach $LogFile (@LogFileList) {
    next if ($LogFile eq 'none');
 	if (!defined($LogFileData{$LogFile}{'logfiles'})) {
-		print "*** Error: There is no logfile defined. Do you have a " . $ConfigDir . "conf/logfiles/" . $LogFile . ".conf file ?\n";
+		print "*** Error: There is no logfile defined. Do you have a " . $BaseDir . "conf/logfiles/" . $LogFile . ".conf file ?\n";
 		next;
 	}
    @FileList = @{$LogFileData{$LogFile}{'logfiles'}};
